# python_runner

[![Tests](https://github.com/alexmojaki/python_runner/actions/workflows/pytest.yml/badge.svg)](https://github.com/alexmojaki/python_runner/actions/workflows/pytest.yml) [![Coverage Status](https://coveralls.io/repos/github/alexmojaki/python_runner/badge.svg?branch=master)](https://coveralls.io/github/alexmojaki/python_runner?branch=master) [![Supports Python version 3.9](https://img.shields.io/pypi/pyversions/python_runner.svg)](https://pypi.python.org/pypi/python_runner)

Helper for running python code indirectly.
